<?php
/**
 * An example file demonstrating how to add all controls.
 *
 * @package     Kirki
 * @category    Core
 * @author      Aristeides Stathopoulos
 * @copyright   Copyright (c) 2017, Aristeides Stathopoulos
 * @license     http://opensource.org/licenses/https://opensource.org/licenses/MIT
 * @since       3.0.12
 */
// Exit if accessed directly.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}
// Do not proceed if Kirki does not exist.
if ( ! class_exists( 'Kirki' ) ) {
	return;
}
/**
 * First of all, add the config.
 *
 * @link https://aristath.github.io/kirki/docs/getting-started/config.html
 */
Kirki::add_config(
	'kirki_demo', array(
		'capability'  => 'edit_theme_options',
		'option_type' => 'theme_mod',
	)
);
/**
 * Add a panel.
 *
 * @link https://aristath.github.io/kirki/docs/getting-started/panels.html
 */
Kirki::add_panel(
	'mountania_options_panel', array(
		'priority'    => 10,
		'title'       => esc_attr__( 'Mountania Options Panel', 'mountania' ),
		'description' => esc_attr__( 'Config Your Theme Options Here.', 'mountania' ),
	)
);
/**
 * Add Sections.
 *
 * We'll be doing things a bit differently here, just to demonstrate an example.
 * We're going to define 1 section per control-type just to keep things clean and separate.
 *
 * @link https://aristath.github.io/kirki/docs/getting-started/sections.html
 */
$sections = array(
	'body'      => array( esc_attr__( 'Main Body Style', 'mountania' ), '' ),
	'colors'	=> array( esc_attr__('Theme Colors', 'mountania'), ''),
	'fonts'	=> array( esc_attr__('Theme Fonts', 'mountania'), ''),
	'page_banner'      => array( esc_attr__( 'Page Banner Style', 'mountania' ), '' ),
	'social'	=> array( esc_attr__('Social Network Links', 'mountania'), ''),
	'footer'	=> array( esc_attr__('Footer Options', 'mountania'), ''),
	'header'	=> array( esc_attr__('Single Post', 'mountania'), ''),
);
foreach ( $sections as $section_id => $section ) {
	$section_args = array(
		'title'       => $section[0],
		'description' => $section[1],
		'panel'       => 'mountania_options_panel',
	);
	if ( isset( $section[2] ) ) {
		$section_args['type'] = $section[2];
	}
	Kirki::add_section( str_replace( '-', '_', $section_id ) . '_section', $section_args );
}
/**
 * A proxy function. Automatically passes-on the config-id.
 *
 * @param array $args The field arguments.
 */
function my_config_kirki_add_field( $args ) {
	Kirki::add_field( 'kirki_demo', $args );
}


// logo max-width
my_config_kirki_add_field(
	array(
		'type'        => 'dimensions',
		'settings'    => 'logo_dimensions',
		'label'       => esc_attr__( 'Logo Dimension Control', 'mountania' ),
		'section'     => 'body_section',
		'default'     => [
			'max-width'  => '180px',
		],
		'choices'     => [
			'labels' => [
				
				'max-width'  => esc_html__( 'Max Width', 'mountania' ),
			],
		],
	)
);

my_config_kirki_add_field(
	array(
		'type'        => 'typography',
		'settings'    => 'title_typo',
		'label'       => esc_attr__( 'Titles Font Family', 'mountania' ),
		'section'     => 'fonts_section',
		'default'     => array(
			'font-family'    => 'Bebas Neue',
		),
		'priority'    => 10,
		'output'      => array(
			array(
				'element' => 'h1, h2, h3, h4, h5, h6',
			),
		),
	)
);

my_config_kirki_add_field(
	array(
		'type'        => 'typography',
		'settings'    => 'text_typo',
		'label'       => esc_attr__( 'Text Font Family', 'mountania' ),
		'section'     => 'fonts_section',
		'default'     => array(
			'font-family'    => 'Cairo',
		),
		'priority'    => 10,
		'output'      => array(
			array(
				'element' => 'body, p, .paragraph',
			),
		),
	)
);

my_config_kirki_add_field(
	array(
		'type'        => 'typography',
		'settings'    => 'menu_typo',
		'label'       => esc_attr__( 'Menu Font Family', 'mountania' ),
		'section'     => 'fonts_section',
		'default'     => array(
			'font-family'    => 'Bebas Neue',
		),
		'priority'    => 10,
		'output'      => array(
			array(
				'element' => '
						.navbar .navbar-nav > li > a,
						.standard-post2 h4,
						.card-post.card-padding h4,
						.single-post-box .post-content blockquote,
						.single-post-box .post-content blockquote p,
						.single-post-box .post-content blockquote:after,
						.about-section2 .highlight-box p,
						footer .widget-area-part ul.tag-list li a,
						footer .widget-area-part div.tagcloud a,
						footer .widget-area-part ul.popular-list li h4
					',
			),
		),
	)
);

my_config_kirki_add_field(
	array(
		'type'        => 'switch',
		'settings'    => 'switch_post_socials',
		'label'       => esc_html__( 'Enable/Disable Social Share Icons in Single Post', 'mountania' ),
		'section'     => 'header_section',
		'default'     => 'off',
		'priority'    => 10,
		'choices'     => [
			'on'  => esc_html__( 'Enable', 'mountania' ),
			'off' => esc_html__( 'Disable', 'mountania' ),
		],
	)
);

/**footer instagram line**/

my_config_kirki_add_field(
	array(
		'type'        => 'image',
		'settings'    => 'image_setting_url',
		'label'       => esc_html__( 'Background Image', 'mountania' ),
		'description' => esc_html__( 'Page Banner Background Image.', 'mountania' ),
		'section'     => 'page_banner_section',
		'default'     => '',
	)
);

my_config_kirki_add_field(
	array(
		'type'        => 'text',
		'settings'    => 'archive_description',
		'label'       => esc_html__( 'Archive Description', 'mountania' ),
		'section'     => 'page_banner_section',
		'default'     => '',
	)
);

my_config_kirki_add_field(
	array(
		'type'        => 'text',
		'settings'    => 'copyright',
		'label'       => esc_html__( 'Copyright Line Text', 'mountania' ),
		'section'     => 'footer_section',
		'default'     => esc_html__( 'Copyright © mountania.', 'mountania' ),
	)
);