<?php
/**
 * Implements the compatibility for the Elementor plugin in mountania  theme.
 *
 * @package    mountania - Themewisdom
 * @subpackage mountania 
 * @since      mountania 1.0
 */


if ( ! function_exists( 'mountania_elementor_active_page_check' ) ) :

	/**
	 * Check whether Elementor plugin is activated and is active on current page or not
	 *
	 * @return bool
	 *
	 * @since mountania 1.0
	 */
	function mountania_Elementor_active_page_check() {
		global $post;

		if ( defined( 'ELEMENTOR_VERSION' ) && get_post_meta( $post->ID, '_elementor_edit_mode', true ) ) {
			return true;
		}

		return false;
	}

endif;

if ( ! function_exists( 'mountania_elementor_widget_render_filter' ) ) :

	/**
	 * Render the default WordPress widget settings, ie, divs
	 *
	 * @param $args the widget id
	 *
	 * @return array register sidebar divs
	 *
	 * @since mountania 1.0
	 */
	function mountania_Elementor_widget_render_filter( $args ) {

		return
			array(
				'before_widget' => '<section class="widget ' . mountania_widget_class_names( $args[ 'widget_id' ] ) . ' clearfix">',
				'after_widget'  => '</section>',
				'before_title'  => '<h2 class="heading2 widget-title">',
				'after_title'   => '</h2>',
			);
	}

endif;

add_filter( 'elementor/widgets/wordpress/widget_args', 'mountania_elementor_widget_render_filter' ); // WPCS: spelling ok.

if ( ! function_exists( 'mountania_widget_class_names' ) ) :

	/**
	 * Render the widget classes for Elementor plugin compatibility
	 *
	 * @param $widgets_id the widgets of the id
	 *
	 * @return mixed the widget classes of the id passed
	 *
	 * @since mountania Custom1.0
	 */
	function mountania_widget_class_names( $widgets_id ) {

		$widgets_id = str_replace( 'wp-widget-', '', $widgets_id );

		$classes = mountania_widgets_classes();

		$return_value = isset( $classes[ $widgets_id ] ) ? $classes[ $widgets_id ] : 'widget_featured_block';

		return $return_value;
	}

endif;


/**
 * Load the mountania Custom Elementor widgets file and registers it
 */
if ( ! function_exists( 'mountania_elementor_widgets_registered' ) ) :

	/**
	 * Load and register the required Elementor widgets file
	 *
	 * @param $widgets_manager
	 *
	 * @since mountania Custom 1.0
	 */
	function mountania_Elementor_widgets_registered( $widgets_manager ) {

		// Require the files
		// 1. Block Widgets
		
		require MOUNTANIA_ELEMENTOR_WIDGETS_DIR . '/text-box.php';
		require MOUNTANIA_ELEMENTOR_WIDGETS_DIR . '/large-carousel.php';
		require MOUNTANIA_ELEMENTOR_WIDGETS_DIR . '/small-carousel.php';
		require MOUNTANIA_ELEMENTOR_WIDGETS_DIR . '/grid-block.php';
		require MOUNTANIA_ELEMENTOR_WIDGETS_DIR . '/popular-block.php';
		require MOUNTANIA_ELEMENTOR_WIDGETS_DIR . '/grid-standard.php';
		require MOUNTANIA_ELEMENTOR_WIDGETS_DIR . '/politic-block.php';
		require MOUNTANIA_ELEMENTOR_WIDGETS_DIR . '/design-block.php';
		require MOUNTANIA_ELEMENTOR_WIDGETS_DIR . '/sport-block.php';
		require MOUNTANIA_ELEMENTOR_WIDGETS_DIR . '/economy-block.php';
		require MOUNTANIA_ELEMENTOR_WIDGETS_DIR . '/most-commented-block.php';
		require MOUNTANIA_ELEMENTOR_WIDGETS_DIR . '/tech-block.php';
		require MOUNTANIA_ELEMENTOR_WIDGETS_DIR . '/science-block.php';
		require MOUNTANIA_ELEMENTOR_WIDGETS_DIR . '/slider-block.php';
		require MOUNTANIA_ELEMENTOR_WIDGETS_DIR . '/slider-block2.php';
		require MOUNTANIA_ELEMENTOR_WIDGETS_DIR . '/fullgrid-block.php';
		require MOUNTANIA_ELEMENTOR_WIDGETS_DIR . '/fullgrid-block2.php';
		require MOUNTANIA_ELEMENTOR_WIDGETS_DIR . '/world-block.php';
		require MOUNTANIA_ELEMENTOR_WIDGETS_DIR . '/trending-block.php';
		require MOUNTANIA_ELEMENTOR_WIDGETS_DIR . '/magic-block.php';
		require MOUNTANIA_ELEMENTOR_WIDGETS_DIR . '/contact-form-block.php';
		require MOUNTANIA_ELEMENTOR_WIDGETS_DIR . '/contact-info-block.php';
		require MOUNTANIA_ELEMENTOR_WIDGETS_DIR . '/page-title.php';
		require MOUNTANIA_ELEMENTOR_WIDGETS_DIR . '/about-block1.php';
		require MOUNTANIA_ELEMENTOR_WIDGETS_DIR . '/about-block2.php';
		require MOUNTANIA_ELEMENTOR_WIDGETS_DIR . '/about-block3.php';
		require MOUNTANIA_ELEMENTOR_WIDGETS_DIR . '/team-block.php';

		

		// Register the widgets
		// 1. Block Widgets
		
		$widgets_manager->register_widget_type( new \Elementor\Mountania_Elementor_Global_Widgets_Large_Carousel() );
		$widgets_manager->register_widget_type( new \Elementor\Mountania_Elementor_Global_Widgets_Small_Carousel() );
		$widgets_manager->register_widget_type( new \Elementor\Mountania_Elementor_Global_Widgets_Grid_block() );
		$widgets_manager->register_widget_type( new \Elementor\Mountania_Elementor_Global_Widgets_Popular_Block() );
		$widgets_manager->register_widget_type( new \Elementor\Mountania_Elementor_Global_Widgets_Grid_Standard() );
		$widgets_manager->register_widget_type( new \Elementor\Mountania_Elementor_Global_Widgets_Politic_Block() );
		$widgets_manager->register_widget_type( new \Elementor\Mountania_Elementor_Global_Widgets_Design_Block() );
		$widgets_manager->register_widget_type( new \Elementor\Mountania_Elementor_Global_Widgets_Sport_Block() );
		$widgets_manager->register_widget_type( new \Elementor\Mountania_Elementor_Global_Widgets_Economy_Block() );
		$widgets_manager->register_widget_type( new \Elementor\Mountania_Elementor_Global_Widgets_Most_Commented() );
		$widgets_manager->register_widget_type( new \Elementor\Mountania_Elementor_Global_Widgets_Tech_Block() );
		$widgets_manager->register_widget_type( new \Elementor\Mountania_Elementor_Global_Widgets_Science_Block() );
		$widgets_manager->register_widget_type( new \Elementor\Mountania_Elementor_Global_Widgets_Slider_Block() );
		$widgets_manager->register_widget_type( new \Elementor\Mountania_Elementor_Global_Widgets_Slider_Block2() );
		$widgets_manager->register_widget_type( new \Elementor\Mountania_Elementor_Global_Widgets_Fullgrid_Block() );
		$widgets_manager->register_widget_type( new \Elementor\Mountania_Elementor_Global_Widgets_Fullgrid_Block2() );
		$widgets_manager->register_widget_type( new \Elementor\Mountania_Elementor_Global_Widgets_World_Block() );
		$widgets_manager->register_widget_type( new \Elementor\Mountania_Elementor_Global_Widgets_Trending_Block() );
		$widgets_manager->register_widget_type( new \Elementor\Mountania_Elementor_Global_Widgets_Magic_Block() );
		$widgets_manager->register_widget_type( new \Elementor\Mountania_Elementor_Global_Widgets_Contact_Block() );
		$widgets_manager->register_widget_type( new \Elementor\Mountania_Elementor_Global_Widgets_Contact_Block2() );
		$widgets_manager->register_widget_type( new \Elementor\Mountania_Elementor_Global_Widgets_Page_Title() );
		$widgets_manager->register_widget_type( new \Elementor\Mountania_Elementor_Global_Widgets_About_Block() );
		$widgets_manager->register_widget_type( new \Elementor\Mountania_Elementor_Global_Widgets_About_Block2() );
		$widgets_manager->register_widget_type( new \Elementor\Mountania_Elementor_Global_Widgets_About_Block3() );
		$widgets_manager->register_widget_type( new \Elementor\Mountania_Elementor_Global_Widgets_Team_Block() );
		
		
	}

endif;

add_action( 'elementor/widgets/widgets_registered', 'mountania_elementor_widgets_registered' );

if ( ! function_exists( 'mountania_elementor_category' ) ) :

	/**
	 * Add the Elementor category for use in mountania Custom widgets as seperator
	 *
	 * @since mountania Custom 1.0
	 */
	function mountania_Elementor_category() {

		// Register widget block category for Elementor section
		\Elementor\Plugin::instance()->elements_manager->add_category( 'mountania-widget-blocks', array(
			'title' => esc_html__( 'mountania Custom Widget Blocks', 'mountania' ),
		), 1 );

		// Register widget grid category for Elementor section
		\Elementor\Plugin::instance()->elements_manager->add_category( 'mountania-widget-grid', array(
			'title' => esc_html__( 'mountania Custom Widget Grid', 'mountania' ),
		), 1 );

		// Register widget global category for Elementor section
		\Elementor\Plugin::instance()->elements_manager->add_category( 'mountania-widget-global', array(
			'title' => esc_html__( 'mountania Custom Global Widgets', 'mountania' ),
		), 1 );
	}

endif;

add_action( 'elementor/init', 'mountania_elementor_category' );

