<?php
/**
 * mountania Elementor Global Widget About_Block3.
 *
 * @package    Mountania - Themewisdom
 * @subpackage Mountania
 * @since      Mountania 1.0
 */

namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) {
	return; // Exit if it is accessed directly
}

class Mountania_Elementor_Global_Widgets_About_Block3 extends Widget_Base {

	/**
	 * Retrieve Mountania_Elementor_Global_Widgets_About_Block3 widget name.
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'Mountania-Global-Widgets-About-Block3';
	}

	/**
	 * Retrieve Mountania_Elementor_Global_Widgets_About_Block3 widget Title.
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Write Us Block', 'mountania' );
	}

	/**
	 * Retrieve Mountania_Elementor_Global_Widget_About_Block3 widget icon.
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'fas fa-pen';
	}

	/**
	 * Retrieve the list of categories the Mountania_Elementor_Global_Widget_About_Block3 widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array( 'mountania-widget-blocks' );
	}
	
	/**
	 * Register Mountania_Elementor_Global_Widget_About_Block3 widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @access protected
	 */
	protected function _register_controls() {

		// Widget title section
		$this->start_controls_section(
			'section_About_Block3_title_manage',
			array(
				'label' => esc_html__( 'Contact Info Block', 'mountania' ),
			)
		);

		$this->add_control(
			'widget_title',
			array(
				'label'       => esc_html__( 'Section Title:', 'mountania' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => esc_html__( 'Add your custom block title', 'mountania' ),
				'label_block' => true,
			)
		);

		$this->add_control(
			'widget_description',
			array(
				'label'       => esc_html__( 'Section Description:', 'mountania' ),
				'type'        => Controls_Manager::TEXTAREA,
				'placeholder' => esc_html__( 'Add your custom block Description', 'mountania' ),
				'label_block' => true,
			)
		);

		$repeater = new Repeater();

		$repeater->add_control(
			'list_title', [
				'label' => __( 'Step Name', 'mountania' ),
				'type' => Controls_Manager::TEXT,
			]
		);

		$repeater->add_control(
			'list_desc', [
				'label' => __( 'Step Description', 'mountania' ),
				'type' => Controls_Manager::TEXT,
			]
		);

		$repeater->add_control(
			'list_icon', [
				'label' => __( 'Step Icon', 'mountania' ),
                'type' => Controls_Manager::ICONS,
                'default' => [
					'value' => 'fas fa-envelope',
					'library' => 'solid',
				],
			]
		);

		$repeater->add_control(
			'list_image', [
				'label' => __( 'Step Image', 'mountania' ),
				'type' => Controls_Manager::MEDIA,
			]
		);

		$this->add_control(
			'list',
			[
				'label' => __( 'Write List Steps', 'mountania' ),
				'type' => Controls_Manager::REPEATER,
				'fields' => $repeater->get_controls(),
				'title_field' => '{{{ list_title }}}',
			]
		);
        
		$this->end_controls_section();

	}

	/**
	 * Render Mountania_Elementor_Global_Widgets_About_Block3 widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @access protected
	 */
	protected function render() {
        $settings = $this->get_settings_for_display();?>
        

        <!-- about-section2 
			================================================== -->
		<section class="about-section2">
            <div class="container">
                
                <div class="about-steps">
                    <div class="title-alternative">
                        <h2><?php echo do_shortcode($settings['widget_title']); ?></h2>
                        <p><?php echo do_shortcode($settings['widget_description']); ?></p>
                    </div>
                    <div class="row">
                        <?php foreach (  $settings['list'] as $item ) { ?>
                            <div class="col-md-4">
                                <div class="step-post">
                                    <div class="image-holder">
                                        <img src="<?php echo esc_attr($item['list_image']['url']); ?>" alt>
                                        <span class="icon">
                                            <?php Icons_Manager::render_icon( $item['list_icon'], [ 'aria-hidden' => 'true' ] ); ?>
                                        </span>
                                    </div>
                                    <h3><?php echo esc_html($item['list_title']); ?></h3>
                                    <span><?php echo esc_html($item['list_desc']); ?></span>
                                </div>
                            </div>
                        <?php } ?>
                    </div>
                </div>
            </div>
		</section>
		<!-- End about section2 -->
			
    
    <?php

	}
}
