<?php
/**
 * mountania Elementor Global Widget Contact_Block.
 *
 * @package    Mountania - Themewisdom
 * @subpackage Mountania
 * @since      Mountania 1.0
 */

namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) {
	return; // Exit if it is accessed directly
}

class Mountania_Elementor_Global_Widgets_Contact_Block extends Widget_Base {

	/**
	 * Retrieve Mountania_Elementor_Global_Widgets_Contact_Block widget name.
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'Mountania-Global-Widgets-Contact-Block';
	}

	/**
	 * Retrieve Mountania_Elementor_Global_Widgets_Contact_Block widget Title.
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Contact Form Block', 'mountania' );
	}

	/**
	 * Retrieve Mountania_Elementor_Global_Widget_Contact_Block widget icon.
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'far fa-envelope';
	}

	/**
	 * Retrieve the list of categories the Mountania_Elementor_Global_Widget_Contact_Block widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array( 'mountania-widget-blocks' );
	}
	
	/**
	 * Register Mountania_Elementor_Global_Widget_Contact_Block widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @access protected
	 */
	protected function _register_controls() {

		// Widget title section
		$this->start_controls_section(
			'section_Contact_Block_title_manage',
			array(
				'label' => esc_html__( 'Contact Form Block', 'mountania' ),
			)
		);

		$this->add_control(
			'widget_title',
			array(
				'label'       => esc_html__( 'Section Title:', 'mountania' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => esc_html__( 'Add your custom block title', 'mountania' ),
				'label_block' => true,
			)
		);

		$this->add_control(
			'widget_description',
			array(
				'label'       => esc_html__( 'Section Description:', 'mountania' ),
				'type'        => Controls_Manager::WYSIWYG,
				'placeholder' => esc_html__( 'Add your custom block Description', 'mountania' ),
				'label_block' => true,
			)
		);

		$this->add_control(
			'widget_contact',
			array(
				'label'       => esc_html__( 'Contact Form 7', 'mountania' ),
				'type'        => Controls_Manager::WYSIWYG,
				'placeholder' => esc_html__( 'Add your Contact Form 7 Shortcode', 'mountania' ),
				'label_block' => true,
			)
		);

		$this->add_control(
			'widget_image',
			array(
				'label'       => esc_html__( 'Image:', 'mountania' ),
				'type'        => Controls_Manager::MEDIA,
				'placeholder' => esc_html__( 'Add your Image', 'mountania' )
			)
		);

		$repeater = new Repeater();

		$repeater->add_control(
			'list_title', [
				'label' => __( 'Social Name', 'mountania' ),
				'type' => Controls_Manager::TEXT,
			]
		);

		$repeater->add_control(
			'list_icon', [
				'label' => __( 'Social Icon', 'mountania' ),
                'type' => Controls_Manager::ICON,
                'include' => [
					'facebook-f',
					'flickr',
					'google-plus',
					'instagram',
					'linkedin',
					'pinterest',
					'reddit',
					'twitch',
					'twitter',
					'vimeo',
					'youtube',
				],
			]
		);

		$repeater->add_control(
			'list_url', [
				'label' => __( 'Social Profile URL', 'mountania' ),
				'type' => Controls_Manager::TEXT,
			]
		);

		$this->add_control(
			'list',
			[
				'label' => __( 'Our Social List', 'mountania' ),
				'type' => Controls_Manager::REPEATER,
				'fields' => $repeater->get_controls(),
				'title_field' => '{{{ list_title }}}',
			]
		);
        
		$this->end_controls_section();

	}

	/**
	 * Render Mountania_Elementor_Global_Widgets_Contact_Block widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @access protected
	 */
	protected function render() {
        $settings = $this->get_settings_for_display();?>
        

            <div class="container">
                <div class="contact-form-box">
                    <div class="row">
                        <div class="col-lg-6">
							<?php if($settings['widget_image']['url']) {?>
								<img src="<?php echo esc_attr($settings['widget_image']['url']); ?>" alt>
							<?php } ?>
                            <div class="contact-text">
                                <h3><?php echo do_shortcode($settings['widget_title']); ?></h3>
								<?php echo do_shortcode($settings['widget_description']); ?>
								<ul class="social-icons">
                                    <?php foreach (  $settings['list'] as $item ) { ?>
                                        <li>
                                            <a href="<?php echo esc_url($item['list_url']); ?>" target="_blank">
                                                <i class="fab fa-<?php echo esc_attr($item['list_icon']); ?>"></i>
                                            </a>
                                        </li>
                                    <?php } ?>
                                </ul>
                            </div>
                        </div>
                        <div class="col-lg-6">
                            <?php echo do_shortcode($settings['widget_contact']); ?>
                        </div>
                    </div>
                </div>
            </div>
			
    
    <?php

	}
}
