<?php
/**
 * mountania Elementor Global Widget Contact_Block2.
 *
 * @package    Mountania - Themewisdom
 * @subpackage Mountania
 * @since      Mountania 1.0
 */

namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) {
	return; // Exit if it is accessed directly
}

class Mountania_Elementor_Global_Widgets_Contact_Block2 extends Widget_Base {

	/**
	 * Retrieve Mountania_Elementor_Global_Widgets_Contact_Block2 widget name.
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'Mountania-Global-Widgets-Contact-Block2';
	}

	/**
	 * Retrieve Mountania_Elementor_Global_Widgets_Contact_Block2 widget Title.
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Contact Info Block', 'mountania' );
	}

	/**
	 * Retrieve Mountania_Elementor_Global_Widget_Contact_Block2 widget icon.
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'fas fa-info-circle';
	}

	/**
	 * Retrieve the list of categories the Mountania_Elementor_Global_Widget_Contact_Block2 widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array( 'mountania-widget-blocks' );
	}
	
	/**
	 * Register Mountania_Elementor_Global_Widget_Contact_Block2 widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @access protected
	 */
	protected function _register_controls() {

		// Widget title section
		$this->start_controls_section(
			'section_Contact_Block2_title_manage',
			array(
				'label' => esc_html__( 'Contact Info Block', 'mountania' ),
			)
		);

		$repeater = new Repeater();

		$repeater->add_control(
			'list_title', [
				'label' => __( 'Contact Info Name', 'mountania' ),
				'type' => Controls_Manager::TEXT,
			]
		);

		$repeater->add_control(
			'list_icon', [
				'label' => __( 'Info Icon', 'mountania' ),
                'type' => Controls_Manager::ICONS,
                'default' => [
					'value' => 'fas fa-envelope',
					'library' => 'solid',
				],
			]
		);

		$repeater->add_control(
			'list_text', [
				'label' => __( 'Info Text', 'mountania' ),
				'type' => Controls_Manager::TEXTAREA,
			]
		);

		$this->add_control(
			'list',
			[
				'label' => __( 'Our Social List', 'mountania' ),
				'type' => Controls_Manager::REPEATER,
				'fields' => $repeater->get_controls(),
				'title_field' => '{{{ list_title }}}',
			]
		);
        
		$this->end_controls_section();

	}

	/**
	 * Render Mountania_Elementor_Global_Widgets_Contact_Block2 widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @access protected
	 */
	protected function render() {
        $settings = $this->get_settings_for_display();?>
        

        <div class="container">
            <div class="contact-info">
                <div class="row">
                    <?php foreach (  $settings['list'] as $item ) { ?>
                        <div class="col-md-4">
                            <div class="info-post">
                                <?php Icons_Manager::render_icon( $item['list_icon'], [ 'aria-hidden' => 'true' ] ); ?>
                                <p><?php echo esc_html($item['list_text']); ?></p>
                            </div>
                        </div>
                    <?php } ?>
                </div>
            </div>
        </div>
			
    
    <?php

	}
}
