<?php
/**
 * mountania Elementor Global Widget Fullgrid_Block2.
 *
 * @package    Mountania - Themewisdom
 * @subpackage Mountania
 * @since      Mountania 1.0
 */

namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) {
	return; // Exit if it is accessed directly
}

class Mountania_Elementor_Global_Widgets_Fullgrid_Block2 extends Widget_Base {

	/**
	 * Retrieve Mountania_Elementor_Global_Widgets_Fullgrid_Block2 widget name.
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'Mountania-Global-Widgets-Fullgrid-Block2';
	}

	/**
	 * Retrieve Mountania_Elementor_Global_Widgets_Fullgrid_Block2 widget Title.
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Full Grid Block 2', 'mountania' );
	}

	/**
	 * Retrieve Mountania_Elementor_Global_Widget_Fullgrid_Block2 widget icon.
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'fas fa-th';
	}

	/**
	 * Retrieve the list of categories the Mountania_Elementor_Global_Widget_Fullgrid_Block2 widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array( 'mountania-widget-blocks' );
	}
	
	/**
	 * Register Mountania_Elementor_Global_Widget_Fullgrid_Block2 widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @access protected
	 */
	protected function _register_controls() {

		// Widget title section
		$this->start_controls_section(
			'section_Fullgrid_Block2_title_manage',
			array(
				'label' => esc_html__( 'FullGrid Block 2', 'mountania' ),
			)
		);

		$this->add_control(
			'widget_title',
			array(
				'label'       => esc_html__( 'Section Title:', 'mountania' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => esc_html__( 'Add your custom block title', 'mountania' ),
				'label_block' => true,
			)
		);

		$this->add_control(
			'title_light',
			array(
				'label'       => esc_html__( 'Switch title Color Mode:', 'mountania' ),
				'type'        => Controls_Manager::SWITCHER,
				'placeholder' => esc_html__( 'Add your custom block title', 'mountania' ),
				'label_on' => __( 'Dark', 'mountania' ),
				'label_off' => __( 'Light', 'mountania' ),
				'return_value' => 'yes',
				'default' => 'yes',
			)
		);

		$this->add_control(
			'title_icon',
			array(
				'label'       => esc_html__( 'Switch title Icon (show/hide):', 'mountania' ),
				'type'        => Controls_Manager::SWITCHER,
				'placeholder' => esc_html__( 'Add your custom block title', 'mountania' ),
				'label_on' => __( 'Show', 'mountania' ),
				'label_off' => __( 'Hide', 'mountania' ),
				'return_value' => 'yes',
				'default' => 'yes',
			)
		);
		
		$this->add_control(
		    'col_number',
		    [
		        'label' => esc_html__( 'Number of Column', 'mountania' ),
                'type' => Controls_Manager::NUMBER,
                'description' => esc_html__('Number of Columns to show', 'mountania'),
                'default' => 4,
				'label_block' => true,
		    ]
        );
        
		$this->add_control(
		    'widget_number',
		    [
		        'label' => esc_html__( 'Posts Number', 'mountania' ),
                'type' => Controls_Manager::NUMBER,
                'description' => esc_html__('Posts number to get from the WP Query (post per page)', 'mountania'),
                'default' => 16,
				'label_block' => true,
		    ]
		);

        $this->add_control(
			'order',
			array(
				'label'       => esc_html__( 'Sort Posts:', 'mountania' ),
				'type'        => Controls_Manager::SELECT,
				'placeholder' => esc_html__( 'Sort Posts by', 'mountania' ),
				'label_block' => true,
				'default' => 'default',
				'options' => array(
					'default'     => esc_html__( 'Default', 'mountania' ),
					'ASC'     => esc_html__( 'ASC', 'mountania' ),
					'DESC' => esc_html__( 'DESC', 'mountania' ),
				),
			)
		);

		$this->add_control(
			'display_type',
			array(
				'label'   => esc_html__( 'Display the Posts from:', 'mountania' ),
				'type'    => Controls_Manager::SELECT,
				'label_block' => true,
				'default' => 'latest',
				'options' => array(
					'latest'     => esc_html__( 'Latest Posts', 'mountania' ),
					'categories' => esc_html__( 'Categories', 'mountania' ),
					'tags' => esc_html__( 'Tags', 'mountania' ),
					'popular' => esc_html__( 'Popular (Most Views)', 'mountania' ),
					'comments' => esc_html__( 'Most Commented', 'mountania' ),
					'custom' => esc_html__( 'Custom Posts with ID\'s', 'mountania' ),
				),
			)
		);

		$categories = get_categories();
	    $category_option = array();
        $category_option['all'] = 'all';
        
	    foreach ($categories as $category) {
	        $category_option[$category->name] = $category->slug;
	    }

		$this->add_control(
			'categories_selected',
			array(
				'label'     => esc_html__( 'Select Category:', 'mountania' ),
				'type'      => Controls_Manager::SELECT,
				'label_block' => true,
				'default' => 'all',
				'options'   => $category_option,
				'condition' => array(
					'display_type' => 'categories',
				),
			)
        );

		$tags = get_tags();
	    $tags_option = array();
        $tags_option['all'] = 'all';
        
	    foreach ($tags as $tag) {
	        $tags_option[$tag->name] = $tag->slug;
	    }

		$this->add_control(
			'tags_selected',
			array(
				'label'     => esc_html__( 'Select Tag:', 'mountania' ),
				'type'      => Controls_Manager::SELECT,
				'label_block' => true,
				'default' => 'all',
				'options'   => $tags_option,
				'condition' => array(
					'display_type' => 'tags',
				),
			)
        );

		$this->add_control(
			'custom_selected',
			array(
				'label'     => esc_html__( 'Add Posts ID', 'mountania' ),
				'type'      => Controls_Manager::TEXT,
                'description' => esc_html__('Write your post ID\'s saparate them with commas (ex: 15,64,225). Try to make equal with posts per page', 'mountania'),
				'label_block' => true,
				'condition' => array(
					'display_type' => 'custom',
				),
			)
        );
        
		$this->end_controls_section();

	}

	/**
	 * Render Mountania_Elementor_Global_Widgets_Fullgrid_Block2 widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @access protected
	 */
	protected function render() {

        $widget_title        = $this->get_settings( 'widget_title' );
        $title_light       = $this->get_settings( 'title_light' );
        $title_icon       = $this->get_settings( 'title_icon' );
        $posts_number        = $this->get_settings( 'widget_number' );
        $col_number        = $this->get_settings( 'col_number' );
		$display_type        = $this->get_settings( 'display_type' );
		$order        = $this->get_settings( 'order' );
		$categories_selected = $this->get_settings( 'categories_selected' );
		$tags_selected = $this->get_settings( 'tags_selected' );
		$custom_selected = $this->get_settings( 'custom_selected' );

        $args = array(
			'posts_per_page'      => $posts_number,
			'post_type'           => 'post',
			'ignore_sticky_posts' => true,
        );
        
        if ( $order != 'default' ) {
			$args[ 'order' ] = $order;
		}

		// Display from the category selected
		if ( $display_type == 'categories' && $categories_selected !== 'all' ) {
			$args[ 'tax_query' ] = array(
				array(
					'taxonomy' => 'category',
					'field'    => 'slug',
					'terms'    => $categories_selected,
				),
			);
		}

		// Display from the tag selected
		if ( $display_type == 'tags' && $tags_selected !== 'all' ) {
			$args['tag'] = $tags_selected;
		}

		// Display from the most commented
		if ( $display_type == 'comments' ) {
			$args['orderby'] = 'comment_count';
		}

		// Display from the most commented
		if ( $display_type == 'popular' ) {
			$args['meta_key'] = 'post_views_count';
			$args['orderby'] = 'meta_value_num';
		}

		// Display from the most commented
		if ( $display_type == 'custom' ) {
            $postsArray = explode(',', $custom_selected );
            
            $postsCustom = array_values($postsArray);
            

			$args['post__in'] = $postsCustom;
		}

		$whiteStyle = 'white-style';
		$noDottes = 'no-dottes';

	?>

    <!-- fullscreen-section 
        ================================================== -->
    <section class="fullscreen-section fixed-images">
        <?php
            if($widget_title) { ?>
				<div class="title-wrapper <?php if(!$title_light) { echo esc_attr($whiteStyle); } ?>">
					<h2 <?php if(!$title_icon) {?> class="<?php echo esc_attr($noDottes); ?>" <?php } ?> >
						<?php echo esc_html($widget_title); ?>
					</h2>
				</div>
			<?php }
        ?>
        <div class="fullscreen-box iso-call col<?php echo esc_attr($col_number); ?>">

                <?php 

                    $query = new \WP_Query($args);

                    if ( $query->have_posts() ) {
                        while ( $query->have_posts() ) {
                            $query->the_post(); ?>
                            <div class="item">
                                <?php
                                    get_template_part( 'template-parts/post-layouts/overlay-post2-image-outside' );
                                ?>
                            </div>
                        <?php }

                        \wp_reset_postdata();
                    } 
                ?>

            </div>
		</section>
		<!-- End recent section -->
			
    
    <?php

	}
}
