<?php
/**
 * mountania Elementor Global Widget Text_Box.
 *
 * @package    Mountania - Themewisdom
 * @subpackage Mountania
 * @since      Mountania 1.0
 */

namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) {
	return; // Exit if it is accessed directly
}

class Mountania_Elementor_Global_Widgets_Text_Box extends Widget_Base {

	/**
	 * Retrieve Mountania_Elementor_Global_Widgets_Text_Box widget name.
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'Mountania-Global-Widgets-Text_Box';
	}

	/**
	 * Retrieve Mountania_Elementor_Global_Widgets_Text_Box widget Title.
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'mountania Text Box', 'mountania' );
	}

	/**
	 * Retrieve Mountania_Elementor_Global_Widget_Text_Box widget icon.
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-t-letter';
	}

	/**
	 * Retrieve the list of categories the Mountania_Elementor_Global_Widget_Text_Box widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array( 'mountania-widget-blocks' );
	}
	
	/**
	 * Register Mountania_Elementor_Global_Widget_Text_Box widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @access protected
	 */
	protected function _register_controls() {

		// Widget title section
		$this->start_controls_section(
			'section_text_box_title_manage',
			array(
				'label' => esc_html__( 'Block Title', 'mountania' ),
			)
		);

		$this->add_control(
			'widget_title',
			array(
				'label'       => esc_html__( 'Title:', 'mountania' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => esc_html__( 'Add your custom block title', 'mountania' ),
				'label_block' => true,
			)
		);
		
		$this->add_control(
		    'description',
		    [
		        'label' => esc_html__( 'Description', 'mountania' ),
		        'type' => Controls_Manager::TEXTAREA,
		        
		    ]
		);

		$this->add_control(
			'text_align',
			[
				'label' => esc_html__( 'Alignment', 'mountania' ),
				'type' => \Elementor\Controls_Manager::CHOOSE,
				'options' => [
					'left' => [
						'title' => esc_html__( 'Left', 'mountania' ),
						'icon' => 'fa fa-align-left',
					],
					'center' => [
						'title' => esc_html__( 'Center', 'mountania' ),
						'icon' => 'fa fa-align-center',
					],
					'right' => [
						'title' => esc_html__( 'Right', 'mountania' ),
						'icon' => 'fa fa-align-right',
					],
				],
				'default' => 'left',
				'toggle' => true,
			]
		);

		$this->add_control(
		    'ex_class',
		    [
				'label' => esc_html__( 'Custom Class', 'mountania' ),
				'description' => esc_html__('add white-style class if you need text to be white color','mountania'),
		        'type' => Controls_Manager::TEXT,
		    ]
		);


		$this->end_controls_section();

	}

	/**
	 * Render Mountania_Elementor_Global_Widgets_Text_Box widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings_for_display();
		if ( ! empty( $settings['widget_title']) ) : ?>

			<!-- text wrapper -->
			<div class="text-wrapper<?php if($settings['ex_class']!=''){ echo ' '.esc_attr($settings['ex_class']); }?>" style="text-align: <?php echo do_shortcode($settings['text_align']);?>">
				<div class="container">
					<h2>
						<?php echo do_shortcode($settings['widget_title']); ?>
					</h2>
					
					<?php if ( ! empty( $settings['description'] ) ){ ?>
						<p class="<?php echo do_shortcode($settings['text_align']);?>">
							<?php echo do_shortcode($settings['description']); ?>
						</p>
					<?php } ?>
				</div>
            </div>
			<!-- End text wrapper -->
			
			<?php
		endif;

	}
}
